@@ -9,19 +9,19 @@
 #include <stdlib.h>
 #include <assert.h>
 
-
 static bool fetchDepends = true;
 
-void SetDownloadListener(IDownloaderProcessUpdateListener listener) {
+void SetDownloadListener(IDownloaderProcessUpdateListener listener)
+{
 	IDownloader::setProcessUpdateListener(listener);
 }
 
 bool isEngineDownload(DownloadEnum::Category cat)
 {
-	return (cat == DownloadEnum::CAT_ENGINE_LINUX)     ||
-	       (cat == DownloadEnum::CAT_ENGINE_LINUX64)   ||
-	       (cat == DownloadEnum::CAT_ENGINE_MACOSX)    ||
-	       (cat == DownloadEnum::CAT_ENGINE_WINDOWS)   ||
+	return (cat == DownloadEnum::CAT_ENGINE_LINUX) ||
+	       (cat == DownloadEnum::CAT_ENGINE_LINUX64) ||
+	       (cat == DownloadEnum::CAT_ENGINE_MACOSX) ||
+	       (cat == DownloadEnum::CAT_ENGINE_WINDOWS) ||
 	       (cat == DownloadEnum::CAT_ENGINE_WINDOWS64);
 }
 
@@ -40,14 +40,12 @@ DownloadEnum::Category getPlatformEngineCat()
 #endif
 }
 
-
 bool download_engine(std::list<IDownload*>& dllist)
 {
 	bool res = true;
 	std::list<IDownload*> enginedls;
 
-
-	for (IDownload* dl: dllist) {
+	for (IDownload* dl : dllist) {
 		if (isEngineDownload(dl->cat)) {
 			enginedls.push_back(dl);
 		}
@@ -56,7 +54,7 @@ bool download_engine(std::list<IDownload*>& dllist)
 		return res;
 
 	httpDownload->download(enginedls);
-	for (const IDownload* dl: enginedls) {
+	for (const IDownload* dl : enginedls) {
 		if (!fileSystem->extractEngine(dl->name, dl->version)) {
 			LOG_ERROR("Failed to extract engine %s", dl->version.c_str());
 			res = false;
@@ -65,13 +63,13 @@ bool download_engine(std::list<IDownload*>& dllist)
 	return res;
 }
 
-//helper function
+// helper function
 IDownload* GetIDownloadByID(std::list<IDownload*>& dllist, int id)
 {
 	std::list<IDownload*>::iterator it;
-	int pos=0;
-	for(it=dllist.begin(); it!=dllist.end(); ++it) {
-		if (pos==id) {
+	int pos = 0;
+	for (it = dllist.begin(); it != dllist.end(); ++it) {
+		if (pos == id) {
 			return *it;
 		}
 		pos++;
@@ -81,16 +79,19 @@ IDownload* GetIDownloadByID(std::list<IDownload*>& dllist, int id)
 }
 
 std::list<IDownload*> searchres;
+std::list<int> downloads;
 
-int DownloadAddByUrl(DownloadEnum::Category cat, const char* filename, const char* url)
+int DownloadAddByUrl(DownloadEnum::Category cat, const char* filename,
+		     const char* url)
 {
-    IDownload* dl = new IDownload(filename, url, cat);
-    dl->addMirror(url);
-    searchres.push_back(dl);
+	IDownload* dl = new IDownload(filename, url, cat);
+	dl->addMirror(url);
+	searchres.push_back(dl);
 	return searchres.size();
 }
 
-bool search(DownloadEnum::Category cat, const char* name, std::list<IDownload*>& searchres)
+bool search(DownloadEnum::Category cat, const char* name,
+	    std::list<IDownload*>& searchres)
 {
 	std::string searchname = name;
 
@@ -98,34 +99,34 @@ bool search(DownloadEnum::Category cat, const char* name, std::list<IDownload*>&
 		cat = getPlatformEngineCat();
 	}
 
-	switch(cat) {
-	case DownloadEnum::CAT_HTTP: //no search possible!
-	case DownloadEnum::CAT_SPRINGLOBBY:{
-		return false;
-	}
-	case DownloadEnum::CAT_MAP:
-	case DownloadEnum::CAT_ENGINE_LINUX:
-	case DownloadEnum::CAT_ENGINE_LINUX64:
-	case DownloadEnum::CAT_ENGINE_WINDOWS:
-	case DownloadEnum::CAT_ENGINE_WINDOWS64:
-	case DownloadEnum::CAT_ENGINE_MACOSX:
-		return httpDownload->search(searchres, searchname.c_str(), cat);
-	case DownloadEnum::CAT_GAME:
-	case DownloadEnum::CAT_COUNT:
-	case DownloadEnum::CAT_NONE:
-		rapidDownload->search(searchres, searchname.c_str(), cat);
-		if (!searchres.empty()) {
-			return true;
+	switch (cat) {
+		case DownloadEnum::CAT_HTTP: // no search possible!
+		case DownloadEnum::CAT_SPRINGLOBBY: {
+			return false;
 		}
-		httpDownload->search(searchres, searchname.c_str(), cat);
-		if (!searchres.empty()) {
-			return true;
-		}
-		return false;
-	default:
-		LOG_ERROR("%s: type invalid", __FUNCTION__);
-		assert(false);
-		return false;
+		case DownloadEnum::CAT_MAP:
+		case DownloadEnum::CAT_ENGINE_LINUX:
+		case DownloadEnum::CAT_ENGINE_LINUX64:
+		case DownloadEnum::CAT_ENGINE_WINDOWS:
+		case DownloadEnum::CAT_ENGINE_WINDOWS64:
+		case DownloadEnum::CAT_ENGINE_MACOSX:
+			return httpDownload->search(searchres, searchname.c_str(), cat);
+		case DownloadEnum::CAT_GAME:
+		case DownloadEnum::CAT_COUNT:
+		case DownloadEnum::CAT_NONE:
+			rapidDownload->search(searchres, searchname.c_str(), cat);
+			if (!searchres.empty()) {
+				return true;
+			}
+			httpDownload->search(searchres, searchname.c_str(), cat);
+			if (!searchres.empty()) {
+				return true;
+			}
+			return false;
+		default:
+			LOG_ERROR("%s: type invalid", __FUNCTION__);
+			assert(false);
+			return false;
 	}
 	return true;
 }
@@ -133,6 +134,7 @@ bool search(DownloadEnum::Category cat, const char* name, std::list<IDownload*>&
 int DownloadSearch(DownloadEnum::Category cat, const char* name)
 {
 	IDownloader::freeResult(searchres);
+	downloads.clear();
 	search(cat, name, searchres);
 	return searchres.size();
 }
@@ -140,8 +142,9 @@ int DownloadSearch(DownloadEnum::Category cat, const char* name)
 bool DownloadGetInfo(int id, downloadInfo& info)
 {
 	IDownload* dl = GetIDownloadByID(searchres, id);
-	if (dl!=NULL) {
-		strncpy(info.filename, dl->name.c_str(), NAME_LEN-1); // -1 because of 0 termination
+	if (dl != NULL) {
+		strncpy(info.filename, dl->name.c_str(),
+			NAME_LEN - 1); // -1 because of 0 termination
 		return true;
 	}
 	return false;
@@ -161,41 +164,39 @@ void DownloadShutdown()
 
 bool DownloadSetConfig(CONFIG type, const void* value)
 {
-	switch(type) {
-	case CONFIG_FILESYSTEM_WRITEPATH:
-		fileSystem->setWritePath((const char*)value);
-		return true;
-	case CONFIG_FETCH_DEPENDS:
-		fetchDepends = (const bool*) value;
-		return true;
-	case CONFIG_RAPID_FORCEUPDATE:
-		rapidDownload->setOption("forceupdate", ""); //FIXME, use value
-		return true;
+	switch (type) {
+		case CONFIG_FILESYSTEM_WRITEPATH:
+			fileSystem->setWritePath((const char*)value);
+			return true;
+		case CONFIG_FETCH_DEPENDS:
+			fetchDepends = (const bool*)value;
+			return true;
+		case CONFIG_RAPID_FORCEUPDATE:
+			rapidDownload->setOption("forceupdate", ""); // FIXME, use value
+			return true;
 	}
 	return false;
 }
 
 bool DownloadGetConfig(CONFIG type, const void** value)
 {
-	switch(type) {
-	case CONFIG_FILESYSTEM_WRITEPATH:
-		*value = fileSystem->getSpringDir().c_str();
-		return true;
-	case CONFIG_FETCH_DEPENDS:
-		*value = (const bool*)fetchDepends;
-		return true;
-	case CONFIG_RAPID_FORCEUPDATE:
-		//FIXME: implement
-		return false;
+	switch (type) {
+		case CONFIG_FILESYSTEM_WRITEPATH:
+			*value = fileSystem->getSpringDir().c_str();
+			return true;
+		case CONFIG_FETCH_DEPENDS:
+			*value = (const bool*)fetchDepends;
+			return true;
+		case CONFIG_RAPID_FORCEUPDATE:
+			// FIXME: implement
+			return false;
 	}
 	return false;
 }
 
-std::list<int> downloads;
-
 bool DownloadAdd(unsigned int id)
 {
-	if ((id>searchres.size())) {
+	if ((id > searchres.size())) {
 		LOG_ERROR("%s Invalid id %d", __FUNCTION__, id);
 		return false;
 	}
@@ -203,9 +204,10 @@ bool DownloadAdd(unsigned int id)
 	return true;
 }
 
-bool dlListContains(const std::list<IDownload*>&dls, const std::string& name)
+bool dlListContains(const std::list<IDownload*>& dls,
+		    const std::string& name)
 {
-	for(const IDownload* dl: dls) {
+	for (const IDownload* dl : dls) {
 		if (dl->name == name) {
 			return true;
 		}
@@ -215,12 +217,12 @@ bool dlListContains(const std::list<IDownload*>&dls, const std::string& name)
 
 bool addDepends(std::list<IDownload*>& dls)
 {
-	for (const IDownload* dl: dls) {
-		for (const std::string& depend: dl->depend) {
+	for (const IDownload* dl : dls) {
+		for (const std::string& depend : dl->depend) {
 			std::list<IDownload*> depends;
 			search(DownloadEnum::CAT_COUNT, depend.c_str(), depends);
 			LOG_INFO("Adding depend %s", depend.c_str());
-			for(IDownload* newdep: depends) {
+			for (IDownload* newdep : depends) {
 				if (!dlListContains(dls, newdep->name)) {
 					dls.push_back(newdep);
 				}
@@ -251,10 +253,9 @@ int DownloadStart()
 		res = 1;
 		return res;
 	}
-
-	if(!rapidDownload->download(dls))
+	if (!rapidDownload->download(dls))
 		res = 2;
-	if (!httpDownload->download(dls,1))
+	if (!httpDownload->download(dls, 1))
 		res = 3;
 	if (!download_engine(dls))
 		res = 4;
@@ -289,7 +290,7 @@ char* CalcHash(const char* str, int size, int type)
 	if (type == 0) {
 		MD5_CTX ctx;
 		MD5Init(&ctx);
-		MD5Update(&ctx, (unsigned char*) str, size);
+		MD5Update(&ctx, (unsigned char*)str, size);
 		MD5Final(&ctx);
 		hash = ctx.digest;
 	} else {
@@ -297,7 +298,7 @@ char* CalcHash(const char* str, int size, int type)
 	}
 
 	std::string encoded = base64_encode(hash, 16);
-	char* ret = (char*) malloc((encoded.size()+1) * sizeof(char));
+	char* ret = (char*)malloc((encoded.size() + 1) * sizeof(char));
 	strncpy(ret, encoded.c_str(), encoded.size());
 	ret[encoded.size()] = '\0';
 	return ret;
