@@ -178,7 +178,7 @@ wxBitmap& IconsCollection::GetFlagBmp(const wxString& country)
 
 wxBitmap& IconsCollection::GetRankBmp(unsigned int rank, bool showLowest)
 {
-	if ((showLowest == false) && (rank == UserStatus::RANK_1)) {
+	if ((!showLowest) && (rank == UserStatus::RANK_1)) {
 		return BMP_RANK_NONE;
 	}
 
@@ -232,7 +232,7 @@ wxBitmap& IconsCollection::GetFractionBmp(const std::string& gameName, size_t fr
 {
 
 	if (gameName.empty() || !LSL::usync().GameExists(gameName)) {
-		wxLogWarning("SideIcon %d for game %s not found!", fractionId, gameName.c_str());
+		wxLogWarning("SideIcon %zu for game %s not found!", fractionId, gameName.c_str());
 		// game doesn't exist, dl needed?!
 		return BMP_EMPTY;
 	}
@@ -276,7 +276,7 @@ wxBitmap& IconsCollection::GetFractionBmp(const std::string& gameName, size_t fr
 wxBitmap IconsCollection::CreateBitmap(const char* const* data)
 {
 	wxImage img = wxImage(data);
-	if (img.HasAlpha() == false) {
+	if (!img.HasAlpha()) {
 		img.InitAlpha();
 	}
 	return wxBitmap(img);
