@@ -243,7 +243,7 @@ MainWindow::MainWindow()
 	Logger::ShowDebugWindow(true);
 	//	Logger::ShowDebugWindow(cfg().ReadBool(_T("/debug")));
 
-	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnUnitsyncReloaded, wxObjectEventFunction(&MainWindow::OnUnitSyncReloaded));
+	SUBSCRIBE_GLOBAL_EVENT(GlobalEventManager::OnUnitsyncReloaded, MainWindow::OnUnitSyncReloaded);
 }
 
 wxBitmap MainWindow::GetTabIcon(const unsigned char* data, size_t size) const
@@ -290,12 +290,12 @@ MainWindow::~MainWindow()
 
 void MainWindow::OnClose(wxCloseEvent& /*unused*/)
 {
+	wxLogWarning("MainWindow::OnClose");
 	Logger::ShowDebugWindow(false);
 	GlobalEventManager::Instance()->Send(GlobalEventManager::OnQuit);
 	//	GlobalEvent::Disconnect(MainWindow::OnClose, GlobalEvent::)
 	//	SetEvtHandlerEnabled(false);
 	{
-		wxWindowUpdateLocker lock(this);
 		SavePerspectives();
 		wxAuiManager* manager = GetAui().manager;
 		if (manager) {
@@ -744,4 +744,3 @@ void MainWindow::OnMenuDownload(wxCommandEvent& /*event*/)
 		start = pos + 1;
 	} while (pos != wxNOT_FOUND);
 }
-
