@@ -111,6 +111,8 @@ bool SpringLobbyApp::OnInit()
 	SetAppName(m_appname);
 #if wxUSE_ON_FATAL_EXCEPTION
 	wxHandleFatalExceptions(!m_crash_handle_disable);
+#else
+	try {
 #endif
 
 	const wxString m_log_file_path = SlPaths::GetLobbyWriteDir() + "springlobby.log";
@@ -130,11 +132,11 @@ bool SpringLobbyApp::OnInit()
 	wxString path = wxPathOnly(wxStandardPaths::Get().GetExecutablePath()) + wxFileName::GetPathSeparator() + _T("locale");
 #else
 #if defined(LOCALE_INSTALL_DIR)
-	wxString path(_T(LOCALE_INSTALL_DIR));
+		wxString path(_T(LOCALE_INSTALL_DIR));
 #else
-	// use a dummy name here, we're only interested in the base path
-	wxString path = wxStandardPaths::Get().GetLocalizedResourcesDir(_T("noneWH"), wxStandardPaths::ResourceCat_Messages);
-	path = path.Left(path.First(_T("noneWH")));
+		// use a dummy name here, we're only interested in the base path
+		wxString path = wxStandardPaths::Get().GetLocalizedResourcesDir(_T("noneWH"), wxStandardPaths::ResourceCat_Messages);
+		path = path.Left(path.First(_T("noneWH")));
 #endif
 #endif
 	m_translationhelper = new wxTranslationHelper(GetAppName().Lower(), path);
@@ -179,7 +181,16 @@ bool SpringLobbyApp::OnInit()
 	wxLogWarning("%s", TowxString(GetSpringlobbyInfo()).c_str());
 
 	ui().OnInit();
-	return true;
+
+#if !wxUSE_ON_FATAL_EXCEPTION
+}
+catch (std::exception& ex)
+{
+	wxLogError(_T("Error had happened: " + wxString(ex.what())));
+}
+#endif
+
+return true;
 }
 
 
@@ -279,5 +290,6 @@ bool SpringLobbyApp::OnCmdLineParsed(wxCmdLineParser& parser)
 
 void SpringLobbyApp::OnQuit(wxCommandEvent& /*data*/)
 {
+	wxLogWarning("MainWindow::OnClose");
 	GlobalEventManager::Instance()->Send(GlobalEventManager::OnQuit);
 }
