@@ -99,7 +99,7 @@ bool TASServer::ExecuteSayCommand(const std::string& cmdstr) //FIXME: all the /c
 	if (arrayparams.empty())
 		return false;
 	const std::string& cmd = arrayparams[0];
-	const std::string& params = LSL::Util::AfterFirst(cmd, " ");
+	const std::string& params = LSL::Util::AfterFirst(cmdstr, " ");
 
 	if ((cmd == "/join") || (cmd == "/j")) {
 		std::string channel;
@@ -463,8 +463,8 @@ void TASServer::Notify()
 		// Nat travelsal "ping"
 		if (BattleExists(m_battle_id)) {
 			IBattle* battle = GetCurrentBattle();
-			if ((battle != nullptr &&
-				battle->GetNatType() == NAT_Hole_punching || (battle->GetNatType() == NAT_Fixed_source_ports)) && !battle->GetInGame()) {
+			if ((battle != nullptr) &&
+			    ((battle->GetNatType() == NAT_Hole_punching) || (battle->GetNatType() == NAT_Fixed_source_ports)) && !battle->GetInGame()) {
 				UdpPingTheServer(GetUserName());
 				if (battle->IsFounderMe()) {
 					UdpPingAllClients();
