@@ -165,7 +165,7 @@ void SlPaths::RefreshSpringVersionList(bool autosearch, const LSL::SpringBundle*
 			usync_paths.push_back(bundle);
 		}
 		if (!SlPaths::IsPortableMode()) {
-/*
+			/*
 //FIXME: reenable when #707 is fixed / spring 102.0 is "established"
 			LSL::SpringBundle systembundle;
 			if (LSL::SpringBundle::LocateSystemInstalledSpring(systembundle)) {
@@ -246,7 +246,8 @@ void SlPaths::ReconfigureUnitsync()
 	LSL::Util::config().ConfigurePaths(
 	    SlPaths::GetCachePath(),
 	    SlPaths::GetUnitSync(),
-	    SlPaths::GetSpringBinary());
+	    SlPaths::GetSpringBinary(),
+	    SlPaths::GetDownloadDir());
 }
 
 
@@ -458,9 +459,9 @@ std::string SlPaths::GetUpdateDir()
 
 void SlPaths::SetDownloadDir(const std::string& newDir)
 {
-	std::string newDownloadDir = LSL::Util::EnsureDelimiter(newDir);
-
+	const std::string newDownloadDir = LSL::Util::EnsureDelimiter(newDir);
 	cfg().Write(_T("/Spring/DownloadDir"), TowxString(newDownloadDir));
+	ReconfigureUnitsync();
 }
 
 bool SlPaths::ValidatePaths()
